# Python Library for Meta1

![](https://img.shields.io/pypi/v/meta1.svg?style=for-the-badge)
![](https://img.shields.io/github/release/meta1/python-meta1.svg?style=for-the-badge)
![](https://img.shields.io/github/downloads/meta1/python-meta1/total.svg?style=for-the-badge)
![](https://img.shields.io/pypi/pyversions/meta1.svg?style=for-the-badge)
![](https://img.shields.io/pypi/l/meta1.svg?style=for-the-badge)
![](https://cla-assistant.io/readme/badge/meta1/python-meta1)

**Stable**

[![docs master](https://readthedocs.org/projects/python-meta1/badge/?version=latest)](http://python-meta1.readthedocs.io/en/latest/)
[![Travis master](https://travis-ci.org/meta1/python-meta1.png?branch=master)](https://travis-ci.org/meta1/python-meta1)
[![codecov](https://codecov.io/gh/meta1/python-meta1/branch/master/graph/badge.svg)](https://codecov.io/gh/meta1/python-meta1)

**Develop**

[![docs develop](https://readthedocs.org/projects/python-meta1/badge/?version=develop)](http://python-meta1.readthedocs.io/en/develop/)
[![Travis develop](https://travis-ci.org/meta1/python-meta1.png?branch=develop)](https://travis-ci.org/meta1/python-meta1)
[![codecov develop](https://codecov.io/gh/meta1/python-meta1/branch/develop/graph/badge.svg)](https://codecov.io/gh/meta1/python-meta1)

---

## Documentation

Visit the [python website](http://docs.pybitshares.com/en/latest/) for in depth documentation on this Python library.

## Installation

### Install with pip3:

    $ sudo apt-get install libffi-dev libssl-dev python-dev python3-dev python3-pip
    $ pip3 install meta1

### Manual installation:

    $ git clone https://github.com/meta-source/meta1-python
    $ cd meta1-python
    $ python3 setup.py install --user

### Upgrade

    $ pip3 install --user --upgrade meta1

## Contributing

python-meta1 welcomes contributions from anyone and everyone. Please
see our [guidelines for contributing](CONTRIBUTING.md) and the [code of
conduct](CODE_OF_CONDUCT.md).

### Discussion and Developers

Discussions around development and use of this library can be found in a
[dedicated Telegram Channel](hhttps://t.me/meta1exchange)

### License

A copy of the license is available in the repository's
[LICENSE](LICENSE.txt) file.

### Bounties

As part of [HackTheDex](https://hackthedex.io), security issues found in this
library are potentially eligible for a bounty.
